
#include <stdbool.h>
#include <stdint.h>

struct gcpointer_t
{
	intptr_t ptr;
	struct gcpointer_t* next;
};

forall(otype T)
struct gcpointer
{
	gcpointer_t internal;
};

forall(otype T)
static inline gcpointer(T) gcmalloc()
{
    gcpointer(T) test;
    return test;
}
